<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "خطا در (غیر) فعال سازی کتابچه نشانه ها",
"id is not set." => "شناسه تعیین نشده",
"Cannot update addressbook with an empty name." => "نمی توانید کتابچه نشانی ها را با یک نام خالی بروزرسانی کنید",
"No ID provided" => "هیچ شناسه ای ارائه نشده",
"Error setting checksum." => "خطا در تنظیم checksum",
"No categories selected for deletion." => "هیچ گروهی برای حذف شدن در نظر گرفته نشده",
"No address books found." => "هیچ کتابچه نشانی پیدا نشد",
"No contacts found." => "هیچ شخصی پیدا نشد",
"element name is not set." => "نام اصلی تنظیم نشده است",
"checksum is not set." => "checksum تنظیم شده نیست",
"Information about vCard is incorrect. Please reload the page." => "اطلاعات درمورد vCard شما اشتباه است لطفا صفحه را دوباره بار گذاری کنید",
"Information about vCard is incorrect. Please reload the page: " => "اطلاعات کارت ویزا شما غلط است لطفا صفحه را دوباره بارگزاری کنید",
"Something went FUBAR. " => "چند چیز به FUBAR رفتند",
"No contact ID was submitted." => "هیچ اطلاعاتی راجع به شناسه ارسال نشده",
"Error reading contact photo." => "خطا در خواندن اطلاعات تصویر",
"Error saving temporary file." => "خطا در ذخیره پرونده موقت",
"The loading photo is not valid." => "بارگزاری تصویر امکان پذیر نیست",
"Contact ID is missing." => "اطلاعات شناسه گم شده",
"No photo path was submitted." => "هیچ نشانی از تصویرارسال نشده",
"File doesn't exist:" => "پرونده وجود ندارد",
"Error loading image." => "خطا در بارگزاری تصویر",
"Error getting contact object." => "خطا در گرفتن اطلاعات شخص",
"Error getting PHOTO property." => "خطا در دربافت تصویر ویژگی شخصی",
"Error saving contact." => "خطا در ذخیره سازی اطلاعات",
"Error resizing image" => "خطا در تغییر دادن اندازه تصویر",
"Error cropping image" => "خطا در برداشت تصویر",
"Error creating temporary image" => "خطا در ساخت تصویر  temporary",
"Error finding image: " => "خطا در پیدا کردن تصویر:",
"Error uploading contacts to storage." => "خطا در هنگام بارگذاری و ذخیره سازی",
"There is no error, the file uploaded with success" => "هیچ خطایی نیست بارگذاری پرونده موفقیت آمیز بود",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "حجم آپلود از طریق Php.ini تعیین می شود",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "حداکثر حجم قابل بار گذاری از طریق HTML MAX_FILE_SIZE است",
"The uploaded file was only partially uploaded" => "پرونده بارگذاری شده فقط تاحدودی بارگذاری شده",
"No file was uploaded" => "هیچ پروندهای بارگذاری نشده",
"Missing a temporary folder" => "یک پوشه موقت گم شده",
"Couldn't save temporary image: " => "قابلیت ذخیره تصویر  موقت وجود ندارد:",
"Couldn't load temporary image: " => "قابلیت بارگذاری تصویر  موقت وجود ندارد:",
"No file was uploaded. Unknown error" => "هیچ فایلی آپلود نشد.خطای ناشناس",
"Contacts" => "اشخاص",
"Select photo" => "تصویر را انتخاب کنید",
"Error" => "خطا",
"Unable to upload your file as it is a directory or has 0 bytes" => "ناتوان در بارگذاری یا فایل یک پوشه است یا 0بایت دارد",
"Upload Error" => "خطا در بار گذاری",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "حجم فایل بسیار بیشتر از حجم تنظیم شده در تنظیمات سرور است",
"Upload too large" => "سایز فایل برای آپلود زیاد است(م.تنظیمات در php.ini)",
"Pending" => "در انتظار",
"No files selected for upload." => "هیچ فایلی برای آپلود انتخاب نشده است",
"Result: " => "نتیجه:",
" imported, " => "وارد شد،",
" failed." => "ناموفق",
"Displayname cannot be empty." => "اسم نمایشی نمی تواند خالی باشد",
"Download" => "بارگیری",
"Edit" => "ویرایش",
"Delete" => "پاک کردن",
"Cancel" => "انصراف",
"Work" => "کار",
"Home" => "خانه",
"Other" => "دیگر",
"Mobile" => "موبایل",
"Text" => "متن",
"Voice" => "صدا",
"Message" => "پیغام",
"Fax" => "دورنگار:",
"Video" => "رسانه تصویری",
"Pager" => "صفحه",
"Internet" => "اینترنت",
"{name}'s Birthday" => "روز تولد {name} است",
"Contact" => "اشخاص",
"Settings" => "تنظیمات",
"Import" => "وارد کردن",
"OK" => "باشه",
"Groups" => "گروه ها",
"Close" => "بستن",
"Add contact" => "افزودن اطلاعات شخص مورد نظر",
"Delete current photo" => "پاک کردن تصویر کنونی",
"Edit current photo" => "ویرایش تصویر کنونی",
"Upload new photo" => "بار گذاری یک تصویر جدید",
"Select photo from ownCloud" => "انتخاب یک تصویر از ابر های شما",
"Additional names" => "نام های دیگر",
"Nickname" => "نام مستعار",
"Enter nickname" => "یک نام مستعار وارد کنید",
"Title" => "عنوان",
"Organization" => "نهاد(ارگان)",
"Birthday" => "روزتولد",
"Add" => "افزودن",
"Phone" => "شماره تلفن",
"Email" => "نشانی پست الکترنیک",
"Address" => "نشانی",
"Note" => "یادداشت",
"Delete contact" => "پاک کردن  اطلاعات شخص مورد نظر",
"Preferred" => "مقدم",
"Please specify a valid email address." => "لطفا یک پست الکترونیکی معتبر وارد کنید",
"Mail to address" => "به نشانی  ارسال شد",
"Delete email address" => "پاک کردن نشانی پست الکترونیکی",
"Enter phone number" => "شماره تلفن راوارد کنید",
"Delete phone number" => "پاک کردن شماره تلفن",
"View on map" => "دیدن روی نقشه",
"City" => "شهر",
"Country" => "کشور",
"Share" => "اشتراک‌گزاری",
"Export" => "خروجی گرفتن",
"The temporary image has been removed from cache." => "تصویر موقت از کش پاک شد.",
"CardDAV syncing addresses" => "CardDAV syncing addresses ",
"more info" => "اطلاعات بیشتر",
"Primary address (Kontact et al)" => "نشانی اولیه",
"iOS/OS X" => "iOS/OS X ",
"Addressbooks" => "کتابچه ی نشانی ها",
"New Address Book" => "کتابچه نشانه های جدید",
"Name" => "نام",
"Save" => "ذخیره سازی"
);
